@@ -14,6 +14,7 @@
 	NSString *name;
 }
 - (Directory *)initWithName:(NSString *)newName;
+- (Directory *)initWithName:(NSString *)newName withContents:(NSMutableArray *)newContents;
 - (NSString *)name;
 - (void)setName:(NSString *)newName;
 - (void)removeItemWithPath:(NSArray *)pathArray;
@@ -28,5 +29,6 @@
 - (NSMutableArray *)recursiveMembers;
 - (void)removeItem:(MyItem *)item;
 - (NSEnumerator *)objectEnumerator;
+- (Directory *)copy;
 
 @end
