@@ -151,7 +151,7 @@
 																							 withRunInMainThread:YES];
 	[updateTable setDisplayStatus:NO];
 	
-	NSString *description = @"Getting track list";
+	NSString *description = NSLocalizedString(@"Downloading Track List", nil);
 	[self addToQueue:getTracks withSubItems:[NSArray arrayWithObjects:updateTable, nil] withDescription:description];
 	[getTracks release];
 	[updateTable release];
@@ -192,7 +192,7 @@
 	duplicatesArray = nil;
 	[njbTable reloadData];
 	[findDuplicatesButton setEnabled:NO];
-	[findDuplicatesStatusField setStringValue:@"Finding Duplicates..."];
+	[findDuplicatesStatusField setStringValue:NSLocalizedString(@"Finding Duplicates...", nil)];
 	// check we have cancelled any other duplicate finding threads
 	[continueFindingDuplicateTracks setValue:NO];
 	[continueFindingDuplicateTracks release];
@@ -286,7 +286,7 @@
 	[deleteTrack cancelItemIfFail:removeFromDuplicatesArray];
 	[deleteTrack cancelItemIfFail:updateTable];
 	
-	NSString *description = [NSString stringWithFormat:@"Deleting track '%@'", [track title]];
+	NSString *description = [NSString stringWithFormat:@"%@ '%@'", NSLocalizedString(@"Deleting track", nil), [track title]];
 	[self addToQueue:deleteTrack withSubItems:[NSArray arrayWithObjects:removeFromItemArray, removeFromDuplicatesArray, updateTable, nil] withDescription:description];
 	
 	[deleteTrack release];
@@ -372,7 +372,7 @@
 	[changeTrackTag cancelItemIfFail:updateTrackList];
 	[changeTrackTag cancelItemIfFail:updateDisplay];
 			
-	NSString *description = [NSString stringWithFormat:@"Changing tag for track '%@'", [oldTrack title]];
+	NSString *description = [NSString stringWithFormat:@"%@ '%@'", NSLocalizedString(@"Changing tag for track", nil), [oldTrack title]];
 	[self addToQueue:changeTrackTag withSubItems:[NSArray arrayWithObjects:updateTrackList, updateDisplay, nil] withDescription:description];
 			
 	[changeTrackTag release];
@@ -390,7 +390,10 @@
 */
 - (void)deleteFromNJB
 {
-	int result = NSRunAlertPanel(@"File Deletion", @"Are you sure you want to delete the selected items off the NJB?", @"No", @"Yes", nil);
+	int result = NSRunAlertPanel(NSLocalizedString(@"File Deletion", nil),
+															 NSLocalizedString(@"Are you sure you want to delete the selected items off the NJB?", nil),
+															 NSLocalizedString(@"No", nil),
+															 NSLocalizedString(@"Yes", nil), nil);
 	if (result == NSAlertDefaultReturn)
 		return;
 	
