@@ -16,10 +16,11 @@
 
 #include "mtp-utils.h"
 
-#define MUSIC_ASSOC 0x0058
-#define PLAYLISTS_ASSOC 0x005c
-#define PICTURES_ASSOC 0x0068
-#define VIDEO_ASSOC 0x006c
+#define PLAYLISTS_ASSOC_NAME @"My Playlists"
+#define MUSIC_ASSOC_NAME @"Music"
+#define PICTURES_ASSOC_NAME @"Pictures"
+#define VIDEO_ASSOC_NAME @"Video"
+#define ZENCAST_ASSOC_NAME @"ZENcast"
 
 @interface NJB : NSObject {
 	IBOutlet StatusDisplayer *statusDisplayer;
@@ -30,9 +31,11 @@
 	unsigned long long totalDiskSpace;
 	unsigned long long freeDiskSpace;
 	NSMutableArray *cachedTrackList;
+	Directory *cachedDataFileList;
 	// this is set when we are getting the track list so
 	// we know the cache should not be used
 	BOOL downloadingTracks;
+	BOOL downloadingFiles;
 	njb_t njbs[NJB_MAX_DEVICES];
 	BOOL turbo;
 	BOOL mtpDevice;
@@ -47,6 +50,12 @@
 	uint8_t interfaceNumber;
 	int batteryLevelMax;
 	unsigned storageID;
+	
+	uint32_t playlistsAssoc;
+	uint32_t musicAssoc;
+	uint32_t picturesAssoc;
+	uint32_t videoAssoc;
+	uint32_t zencastAssoc;
 }
 
 - (NJBTransactionResult *)connect;
@@ -58,6 +67,7 @@
 - (BOOL)isConnected;
 - (NSMutableArray *)tracks;
 - (NSMutableArray *)cachedTrackList;
+- (Directory *)cachedDataFileList;
 - (Directory *)dataFiles;
 - (NSMutableArray *)playlists;
 - (NJBTransactionResult *)deleteTrack:(Track *)track;
@@ -91,6 +101,11 @@
 - (NSString *)batteryStatus;
 - (void)setTurbo:(BOOL) newTurbo;
 - (int)batteryLevelMax;
+- (uint32_t)playlistsAssoc;
+- (uint32_t)musicAssoc;
+- (uint32_t)picturesAssoc;
+- (uint32_t)videoAssoc;
+- (uint32_t)zencastAssoc;
 
 int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
 int progressPTP(u_int32_t sent, u_int32_t total);
