@@ -62,6 +62,15 @@ StatusDisplayer *statusDisplayerGlobal;
 		// this defined for the non MTP devices
 		batteryLevelMax = 100;
 		storageID = 0;
+		
+		downloadingTracks = NO;
+		downloadingFiles = NO;
+		
+		playlistsAssoc = 0;
+		musicAssoc = 0;
+		picturesAssoc = 0;
+		videoAssoc = 0;
+		zencastAssoc = 0;
 	}
 	return self;
 }
@@ -133,6 +142,31 @@ StatusDisplayer *statusDisplayerGlobal;
 	return batteryLevelMax;
 }
 
+- (uint32_t)playlistsAssoc
+{
+	return playlistsAssoc;
+}
+
+- (uint32_t)musicAssoc
+{
+	return musicAssoc;
+}
+
+- (uint32_t)picturesAssoc
+{
+	return picturesAssoc;
+}
+
+- (uint32_t)videoAssoc
+{
+	return videoAssoc;
+}
+
+- (uint32_t)zencastAssoc
+{
+	return zencastAssoc;
+}
+
 /**********************/
 
 - (void)awakeFromNib
@@ -305,6 +339,9 @@ StatusDisplayer *statusDisplayerGlobal;
 			batteryLevelMax = *(uint8_t *)dpd.FORM.Range.MaximumValue;	
 		
 		ptp_free_devicepropdesc(&dpd);
+		
+		// download the data files to the cache
+		[self dataFiles];
 	}
 	else
 	{
@@ -521,6 +558,7 @@ StatusDisplayer *statusDisplayerGlobal;
 			{
 				// todo: print error
 				NSLog(@"Could not get object handles...");
+				downloadingTracks = NO;
 				return nil;
 			}
 		}
@@ -692,7 +730,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		}
 		
 		if (send_file(&params, [[track fullPath] fileSystemRepresentation], [[[track fullPath] lastPathComponent] fileSystemRepresentation],
-									format, &progressPTP, &handle, MUSIC_ASSOC) != PTP_RC_OK)
+									format, &progressPTP, &handle, [self musicAssoc]) != PTP_RC_OK)
 		{
 			NSString *error = @"Error uploading file";
 			NSLog(error);
@@ -921,10 +959,19 @@ StatusDisplayer *statusDisplayerGlobal;
 {
 	if (![self isConnected])
 		return nil;
+	if (cachedDataFileList)
+	{
+		return [self cachedDataFileList];
+	}
+	
+	downloadingFiles = YES;
+	
+	cachedDataFileList = [[Directory alloc] init];
+	// a better name for here...
+	Directory *baseDir = cachedDataFileList;
 	
 	if (!mtpDevice)
 	{
-		Directory *baseDir = [[Directory alloc] init];
 		NJB_Reset_Get_Datafile_Tag(njb);
 		njb_datafile_t *filetag;
 		while (filetag = NJB_Get_Datafile_Tag(njb))
@@ -982,21 +1029,18 @@ StatusDisplayer *statusDisplayerGlobal;
 			
 			NJB_Datafile_Destroy(filetag);
 		}
-		
-		return [baseDir autorelease];
 	}
 	else
 	{
 		PTPObjectInfo oi;
 		
-		Directory *baseDir = [[Directory alloc] init];
-		
 		if (params.handles.Handler == NULL)
 		{
 			if (ptp_getobjecthandles(&params,PTP_GOH_ALL_STORAGE, PTP_GOH_ALL_FORMATS, PTP_GOH_ALL_ASSOCS, &params.handles) != PTP_RC_OK)
 			{
 				// todo: print error
 				NSLog(@"Could not get object handles...");
+				downloadingFiles = NO;
 				return nil;
 			}
 		}
@@ -1005,6 +1049,38 @@ StatusDisplayer *statusDisplayerGlobal;
 		for (i = 0; i < params.handles.n; i++) {
 			if (ptp_getobjectinfo(&params,params.handles.Handler[i], &oi) == PTP_RC_OK)
 			{
+				if (oi.ObjectFormat == PTP_OFC_Association)
+				{
+					// store the base directories
+					NSString *assocName = [NSString stringWithUTF8String:oi.Filename];
+					
+					if ([assocName isEqualToString:PLAYLISTS_ASSOC_NAME])
+					{
+						playlistsAssoc = params.handles.Handler[i];
+						NSLog(@"using playlistsAssoc 0x%04x", playlistsAssoc);
+					}
+					else if ([assocName isEqualToString:MUSIC_ASSOC_NAME])
+					{
+						musicAssoc = params.handles.Handler[i];
+						NSLog(@"using musicAssoc 0x%04x", musicAssoc);
+					}
+					if ([assocName isEqualToString:PICTURES_ASSOC_NAME])
+					{
+						picturesAssoc = params.handles.Handler[i];
+						NSLog(@"using picturesAssoc 0x%04x", picturesAssoc);
+					}
+					if ([assocName isEqualToString:VIDEO_ASSOC_NAME])
+					{
+						videoAssoc = params.handles.Handler[i];
+						NSLog(@"using videoAssoc 0x%04x", videoAssoc);
+					}
+					if ([assocName isEqualToString:ZENCAST_ASSOC_NAME])
+					{
+						zencastAssoc = params.handles.Handler[i];
+						NSLog(@"using zencastAssoc 0x%04x", zencastAssoc);
+					}
+				}
+				
 				if (oi.ObjectFormat == PTP_OFC_Association ||	oi.ObjectFormat == PTP_OFC_WAV || oi.ObjectFormat == PTP_OFC_MP3 || oi.ObjectFormat == PTP_OFC_WMA)
 					continue;
 				
@@ -1019,9 +1095,10 @@ StatusDisplayer *statusDisplayerGlobal;
 				[dataFile release];
 			}
 		}
-		
-		return [baseDir autorelease];
 	}
+	
+	downloadingFiles = NO;
+	return [self cachedDataFileList];
 }
 
 - (NJBTransactionResult *)downloadFile:(DataFile *)dataFile
@@ -1092,62 +1169,64 @@ StatusDisplayer *statusDisplayerGlobal;
 		
 		uint32_t parenthandle = 0;
 		
-		// a test to see how the player works with video & images
+		// a test to see how the player works with video & images. We really should
+		// implement the full directory structure for MTP and just upload to the folder
+		// we've been told to here.
 		NSString *extension = [[[dataFile fullPath] pathExtension] lowercaseString];
 		if ([extension isEqualToString:@"wmv"])
 		{
 			objectFormat = PTP_OFC_WMV;
-			parenthandle = VIDEO_ASSOC;
+			parenthandle = [self videoAssoc];
 		}
 		else if ([extension isEqualToString:@"avi"])
 		{
 			objectFormat = PTP_OFC_AVI;
-			parenthandle = VIDEO_ASSOC;
+			parenthandle = [self videoAssoc];
 		}
 		else if ([extension isEqualToString:@"mpg"] || [extension isEqualToString:@"mpeg"])
 		{
 			objectFormat = PTP_OFC_MPEG;
-			parenthandle = VIDEO_ASSOC;
+			parenthandle = [self videoAssoc];
 		}
 		else if ([extension isEqualToString:@"asf"])
 		{
 			objectFormat = PTP_OFC_ASF;
-			parenthandle = VIDEO_ASSOC;
+			parenthandle = [self videoAssoc];
 		}
 		else if ([extension isEqualToString:@"qt"])
 		{
 			objectFormat = PTP_OFC_QT;
-			parenthandle = VIDEO_ASSOC;
+			parenthandle = [self videoAssoc];
 		}
 		else if ([extension isEqualToString:@"jpg"] || [extension isEqualToString:@"jpeg"])
 		{
 			objectFormat = PTP_OFC_EXIF_JPEG;
-			parenthandle = PICTURES_ASSOC;
+			parenthandle = [self picturesAssoc];
 		}
 		else if ([extension isEqualToString:@"tif"] || [extension isEqualToString:@"tiff"])
 		{
 			objectFormat = PTP_OFC_TIFF;
-			parenthandle = PICTURES_ASSOC;
+			parenthandle = [self picturesAssoc];
 		}
 		else if ([extension isEqualToString:@"bmp"])
 		{
 			objectFormat = PTP_OFC_BMP;
-			parenthandle = PICTURES_ASSOC;
+			parenthandle = [self picturesAssoc];
 		}
 		else if ([extension isEqualToString:@"gif"])
 		{
 			objectFormat = PTP_OFC_GIF;
-			parenthandle = PICTURES_ASSOC;
+			parenthandle = [self picturesAssoc];
 		}
 		else if ([extension isEqualToString:@"pict"])
 		{
 			objectFormat = PTP_OFC_PICT;
-			parenthandle = PICTURES_ASSOC;
+			parenthandle = [self picturesAssoc];
 		}
 		else if ([extension isEqualToString:@"png"])
 		{
 			objectFormat = PTP_OFC_PNG;
-			parenthandle = PICTURES_ASSOC;
+			parenthandle = [self picturesAssoc];
 		}
 		
 		NSLog(@"uploading file with object format 0x%.02x", objectFormat);
@@ -1669,6 +1748,16 @@ int progressPTP(u_int32_t sent, u_int32_t total)
 		return nil;
 }
 
+- (Directory *)cachedDataFileList
+{
+	if (cachedDataFileList && !downloadingFiles)
+	{
+		return [cachedDataFileList copy];
+	}
+	else
+		return nil;
+}
+
 /* returns a string rounded to 1dp for
  * the rate given
  */
