@@ -5,7 +5,6 @@
 
 #import <Cocoa/Cocoa.h>
 #import "MyTableTab.h"
-#import "MyMutableArray.h"
 
 @interface PlaylistsTab : MyTableTab
 {
@@ -19,9 +18,9 @@
 	IBOutlet NSButton *deletePlaylistButton;
 	IBOutlet NSButton *moveTracksUpButton;
 	IBOutlet NSButton *moveTracksDownButton;
-	MyMutableArray *playlists;
-	MyMutableArray *tracksInCurrentPlaylist;
-	BOOL trackListIsUpToDate;
+	NSMutableArray *playlists;
+	NSMutableArray *tracksInCurrentPlaylist;
+	BOOL trackListUpToDate;
 }
 - (IBAction)addToPlaylist:(id)sender;
 - (IBAction)deleteFromPlaylist:(id)sender;
@@ -31,11 +30,9 @@
 - (IBAction)moveTracksDown:(id)sender;
 - (void)loadTracks;
 - (NJBTransactionResult *)downloadTrackList;
-- (void)updateTracks;
 - (void)loadPlaylists;
 - (NJBTransactionResult *)downloadPlaylists;
 - (void)updateJukeboxPlaylist:(Playlist *)playlist;
 - (void)deleteJukeboxPlaylist:(Playlist *)playlist;
-- (BOOL)trackListIsUpToDate;
 
 @end
