@@ -113,6 +113,17 @@
 	[duplicatesArtistTol setIntValue:[preferences artistTol]];
 	[duplicatesArtistTolStepper setIntValue:[preferences artistTol]];
 	
+	[self setStateForButton:iTunesIntegration fromBool:[preferences iTunesIntegration]];
+	if (![preferences iTunesIntegration])
+	{
+		[downloadedTrackDir setEnabled:NO];
+	}
+	else
+	{
+		[downloadedTrackDir setEnabled:YES];
+		[downloadedTrackDir setStringValue:[preferences downloadDir]];
+	}
+	
 	// start with no changes
 	// this goes at the end as setting text above causes boxes to call controlTextDidChange
 	isDirty = NO;
@@ -184,6 +195,16 @@
 	[preferences setTitleTol:[duplicatesTitleTol intValue]];
 	[preferences setArtistTol:[duplicatesArtistTol intValue]];
 	
+	if ([iTunesIntegration state] == NSOnState)
+	{
+		[preferences setiTunesIntegration:YES];
+		[preferences setDownloadDir:[downloadedTrackDir stringValue]];
+	}
+	else
+	{
+		[preferences setiTunesIntegration:NO];
+	}
+	
 	[self close];
 }
 
@@ -368,4 +389,17 @@
 	return NO;
 }
 
+- (IBAction)iTunesIntegration:(id)sender
+{
+	if ([iTunesIntegration state] == NSOnState)
+	{	
+		[downloadedTrackDir setEnabled:YES];
+	}
+	else
+	{
+		[downloadedTrackDir setEnabled:NO];
+	}
+	isDirty = YES;
+}
+
 @end
