@@ -52,6 +52,10 @@
 #define DEFAULT_DUPLICATES_ARTIST_TOL [NSNumber numberWithInt:2]
 #define PREF_KEY_TURBO @"turbo"
 #define DEFAULT_TURBO [NSNumber numberWithBool:YES]
+#define PREF_KEY_ITUNES_INTEGRATION @"iTunesIntegration"
+#define DEFAULT_PREF_KEY_ITUNES_INTEGRATION [NSNumber numberWithBool:NO]
+#define PREF_KEY_DOWNLOAD_DIR @"downloadDir"
+#define DEFAULT_PREF_KEY_DOWNLOAD_DIR @"~/Music/XNJB/"
 // Notifications
 #define NOTIFICATION_CONNECTED @"XNJBConnected"
 #define NOTIFICATION_DISCONNECTED @"XNJBDisconnected"
