@@ -483,7 +483,8 @@
 
     if (repad) 
     {
-        NSFileHandle *sourceFile = [[NSFileHandle fileHandleForReadingAtPath: path] retain];
+			// fix by RAL 20060402: should not retain this
+        NSFileHandle *sourceFile = [NSFileHandle fileHandleForReadingAtPath: path];
         // jump over the old tag and start appending the file data to the new file.
         if (present) [sourceFile seekToFileOffset:tagLength+10+positionInFile];
         
@@ -499,7 +500,8 @@
         [sourceFile closeFile];
         [fileManager removeFileAtPath:path handler:NULL];
         [fileManager movePath:writePath toPath:path handler:NULL];
-        [fileManager removeFileAtPath:writePath handler:NULL];
+				// fix by RAL 20060402: no need to delete writePath since we've just moved it!
+//        [fileManager removeFileAtPath:writePath handler:NULL];
     } else 
     {
         [file closeFile];
