@@ -243,6 +243,23 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp,
 	/* read first(?) part of data */
 	ret=params->read_func((unsigned char *)&usbdata,
 			sizeof(usbdata), params->data);
+	
+/*	{
+	int i = 0;
+	 
+		 printf("-------------------------\n");
+		 printf("got data size %d\n", sizeof(usbdata));
+		 for (i = 0; i < sizeof(usbdata); i += 8)
+		 {
+			 int j = i;
+			 for (; j<sizeof(usbdata) && j<i+8; j++)
+				 printf("0x%02x ", ((unsigned char *)&usbdata)[j]);
+			 printf("\n");
+		 }
+		 printf("-------------------------\n");
+	 }
+*/
+
 	if (ret!=PTP_RC_OK) {
 		ret = PTP_ERROR_IO;
 	} else
@@ -254,6 +271,9 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp,
 	} else {
 		/* evaluate data length */
 		len=dtoh32(usbdata.length)-PTP_USB_BULK_HDR_LEN;
+		/* test by RAL: some data coming back has this length - how do we deal with it? */
+		if (dtoh32(usbdata.length) == 0xffffffff)
+			len = 0x1fffff;
 		/* allocate memory for data if not allocated already */
 		if (*data==NULL) *data=calloc(len,1);
 		
