@@ -27,7 +27,7 @@
 #include "libptp-endian.h"
 
 /** The callback type */
-typedef int Progress_Callback(u_int32_t sent, u_int32_t total);
+typedef int Progress_Callback(uint32_t sent, uint32_t total);
 
 /* PTP datalayer byteorder */
 
