@@ -407,16 +407,6 @@ uint16_t send_file(PTPParams* params, const char* filename, const char* friendly
 	newInfo.ObjectFormat = objectFormat;
 	newInfo.ObjectCompressedSize = filesize;
 	
-	// check the parenthandle exists
-	// this is temporary since we are uploading media of different types to hardcoded directories
-	// which may not exist
-	PTPObjectInfo parentInfo;
-	if (ptp_getobjectinfo(params, parenthandle, &parentInfo) != PTP_RC_OK)
-	{
-		printf("Parent handle 0x%04x does not exist, uploading to root dir\n", parenthandle);
-		parenthandle = 0;
-	}
-	
 	ret = ptp_sendobjectinfo(params, &store, &parenthandle, handle, &newInfo);
 	if (ret != PTP_RC_OK)
 	{
